==> externalVector_1.0.3.tar.gz: externalVector/man/allIndex-class.Rd <==
\name{allIndex-class}
\docType{class}
\alias{allIndex-class}
\alias{Arith,numeric,allIndex-method}
\alias{Arith,allIndex,numeric-method}
\alias{[,allIndex,ANY,missing,missing-method}
\alias{[,allIndex,missing,missing,missing-method}
\alias{[<-,allIndex,ANY,ANY,ANY-method}
\alias{[[<-,allIndex-method}
\alias{all.na,allIndex-method}
\alias{any.na,allIndex-method}
\alias{initialize,allIndex-method}
\alias{length,allIndex-method}
\alias{length<-,allIndex-method}
\alias{dim<-,allIndex,ANY-method}

\title{Class "allIndex", index class representing a subscript for all
  elements of a vector or an array dimension }
\description{ When used as a subscript for a vector object \code{x},
  this is equivalent to \code{seq(length(x))}. When used as a subscript for
  the \code{i}-th dimension of an array object \code{x}, this is
  equivalent to \code{seq(dim(x)[i])}. }
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("allIndex")}.
Objects from this class can not be modified and they are all equivalent.
}
\section{Slots}{
  \describe{
    \item{\code{.Data}:}{Object of class \code{"logical"}, this is
      always equal to \code{TRUE}. }
  }
}
\section{Extends}{
Class \code{"logical"}, directly.
Class \code{"vectorIndex"}, directly.
}
\section{Methods}{
  Signature components for the methods are:

  \tabular{ll}{
    x \tab The class "allIndex"\cr
    scalar \tab Length one positive "integer"\cr
    i \tab The class "ANY"\cr
    value \tab The class "ANY"\cr
    .Object \tab The class "allIndex"\cr
  }

  \describe{
    \item{\code{x+scalar}:}{ Add \code{scalar} to \code{x}.
      Result is \code{x}. }
    \item{\code{scalar+x}:}{ Add \code{scalar} to \code{x}.
      Result is \code{x}. }
    \item{\code{x*scalar}:}{ Multiply \code{x} by \code{scalar}.
      Result is \code{x}. }
    \item{\code{scalar*x}:}{ Multiply \code{x} by \code{scalar}.
      Result is \code{x}. }
    \item{dim(x) <- value}{ Set a dimension on \code{x}. If value is of
      length 2, this may create a "matrixIndex". }
    \item{\code{x[i]}:}{ Subset x. Result is i. }
    \item{\code{x[]}:}{ Subset x with the subscript missing. Result is x. }
    \item{\code{x[i] <- value}:}{ Subassign x. Results in an error (as
      objects from class \code{"allIndex"} are not mutable. }
    \item{\code{x[[i]] <- value}:}{ Subassign x. Results in an error (as
      objects from class \code{"allIndex"} are not mutable. }
    \item{\code{all.na(x)}:}{ Are all elements of \code{x} \code{NA}? Result is
      always \code{FALSE}. }
    \item{\code{any.na(x)}:}{ Is any element of \code{x} \code{NA}? Result is
      always \code{FALSE}. }
    \item{\code{initialize(.Object)}:}{Initialize an object from class
      \code{"allIndex"}. }
    \item{\code{length(x)}:}{ Return the length of \code{x} which is always
      \code{Inf}. }
    \item{\code{length(x) <- value}:}{ Modify the length of \code{x}. Always
      results in an error. }
  }
}
\seealso{
  \code{\link{vectorIndex-class}} for the super class of \code{"allIndex"}.
}
\keyword{classes}
\keyword{methods}

==> externalVector_1.4.0.tar.gz: externalVector/man/allIndex-class.Rd <==
\name{allIndex-class}
\docType{class}
\alias{allIndex-class}
\alias{Arith,numeric,allIndex-method}
\alias{Arith,allIndex,numeric-method}
\alias{[,allIndex,ANY,missing,missing-method}
\alias{[,allIndex,missing,missing,missing-method}
\alias{[<-,allIndex,ANY,ANY,ANY-method}
\alias{[[<-,allIndex-method}
\alias{allNA,allIndex-method}
\alias{anyNA,allIndex-method}
\alias{initialize,allIndex-method}
\alias{length,allIndex-method}
\alias{length<-,allIndex-method}
\alias{dim<-,allIndex,ANY-method}

\title{Class "allIndex", index class representing a subscript for all
  elements of a vector or an array dimension }
\description{ When used as a subscript for a vector object \code{x},
  this is equivalent to \code{seq(length(x))}. When used as a subscript for
  the \code{i}-th dimension of an array object \code{x}, this is
  equivalent to \code{seq(dim(x)[i])}. }
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("allIndex")}.
Objects from this class can not be modified and they are all equivalent.
}
\section{Slots}{
  \describe{
    \item{\code{.Data}:}{Object of class \code{"logical"}, this is
      always equal to \code{TRUE}. }
  }
}
\section{Extends}{
Class \code{"logical"}, directly.
Class \code{"vectorIndex"}, directly.
}
\section{Methods}{
  Signature components for the methods are:

  \tabular{ll}{
    x \tab The class "allIndex"\cr
    scalar \tab Length one positive "integer"\cr
    i \tab The class "ANY"\cr
    value \tab The class "ANY"\cr
    .Object \tab The class "allIndex"\cr
  }

  \describe{
    \item{\code{x+scalar}:}{ Add \code{scalar} to \code{x}.
      Result is \code{x}. }
    \item{\code{scalar+x}:}{ Add \code{scalar} to \code{x}.
      Result is \code{x}. }
    \item{\code{x*scalar}:}{ Multiply \code{x} by \code{scalar}.
      Result is \code{x}. }
    \item{\code{scalar*x}:}{ Multiply \code{x} by \code{scalar}.
      Result is \code{x}. }
    \item{dim(x) <- value}{ Set a dimension on \code{x}. If value is of
      length 2, this may create a "matrixIndex". }
    \item{\code{x[i]}:}{ Subset x. Result is i. }
    \item{\code{x[]}:}{ Subset x with the subscript missing. Result is x. }
    \item{\code{x[i] <- value}:}{ Subassign x. Results in an error (as
      objects from class \code{"allIndex"} are not mutable. }
    \item{\code{x[[i]] <- value}:}{ Subassign x. Results in an error (as
      objects from class \code{"allIndex"} are not mutable. }
    \item{\code{allNA(x)}:}{ Are all elements of \code{x} \code{NA}? Result is
      always \code{FALSE}. }
    \item{\code{anyNA(x)}:}{ Is any element of \code{x} \code{NA}? Result is
      always \code{FALSE}. }
    \item{\code{initialize(.Object)}:}{Initialize an object from class
      \code{"allIndex"}. }
    \item{\code{length(x)}:}{ Return the length of \code{x} which is always
      \code{Inf}. }
    \item{\code{length(x) <- value}:}{ Modify the length of \code{x}. Always
      results in an error. }
  }
}
\seealso{
  \code{\link{vectorIndex-class}} for the super class of \code{"allIndex"}.
}
\keyword{classes}
\keyword{methods}
